/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
/**
 * Standard job response document
 * Represents the attributes and status of a z/OS batch job
 * @export
 * @interface IJob
 */
export interface IJob {
    /**
     * job id for a job
     * Uniquely identifies a job on a z/OS system
     * @type {string}
     * @memberof IJob
     */
    jobId?: string;
    /**
     * job name for a job
     * @type {string}
     * @memberof IJob
     */
    jobName?: string;
    /**
     * The primary or secondary JES subsystem.
     * If this value is null, the job was processed by the primary subsystem.
     * @type {string}
     * @memberof IJob
     */
    subsystem?: string;
    /**
     * owner of the job
     * @type {string}
     * @memberof IJob
     */
    owner?: string;
    /**
     * status of the job
     * @type {string}
     * @memberof IJob
     */
    status?: string;
    /**
     * type of job
     * @type {string}
     * @memberof IJob
     */
    type?: string;
    /**
     * job class
     * @type {string}
     * @memberof IJob
     */
    executionClass?: string;
    /**
     * return code of the job
     * @type {string}
     * @memberof IJob
     */
    returnCode?: string;
    /**
     * job phase
     * @type {number}
     * @memberof IJob
     */
    phaseName?: string;
    /**
     * execution system
     * @type {string}
     * @memberof IJob
     */
    execSystem?: string;
    /**
     * execution member
     * @type {string}
     * @memberof IJob
     */
    execMember?: string;
    /**
     * system entry time stamp
     * @type {string}
     * @memberof IJob
     */
    systemEntryDateTime?: string;
    /**
     * system output class
     * @type {string}
     * @memberof IJob
     */
    sysoutClass?: string;
    /**
     * output node
     * @type {string}
     * @memberof IJob
     */
    outputNode?: string;
    /**
     * execute node
     * @type {string}
     * @memberof IJob
     */
    execNode?: string;
    /**
     * device name
     * @type {string}
     * @memberof IJob
     */
    device?: string;
    /**
     * priority
     * @type {string}
     * @memberof IJob
     */
    priority?: string;
    /**
     * job key
     * @type {string}
     * @memberof IJob
     */
    jobKey?: string;
    /**
     * data token
     * @type {string}
     * @memberof IJob
     */
    dataToken?: string;
    /**
     * spool tracks
     * @type {string}
     * @memberof IJob
     */
    spoolTracks?: string;
    /**
     * security label
     * @type {string}
     * @memberof IJob
     */
    secLabel?: string;
    /**
     * flag bytes
     * @type {string}
     * @memberof IJob
     */
    flagByte?: string;
    /**
     * programmer
     * @type {string}
     * @memberof IJob
     */
    programmer?: string;
    /**
     * job position
     * @type {string}
     * @memberof IJob
     */
    position?: string;
    /**
     * address space id
     * @type {string}
     * @memberof IJob
     */
    asID?: string;
    /**
     * phase
     * @type {string}
     * @memberof IJob
     */
    phase?: number;
}
