/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../../api/doc/IRestApiResponse';
/**
 * Class to handle deletion of job information
 * @export
 * @class CancelJobs
 */
export declare class CancelJobs {
    /**
     * Cancel and purge a job
     * @static
     * @param {Session}         session     - connection info
     * @param {string}          jobname     - job name to be translated into parms object
     * @param {string}          jobid       - job id to be translated into parms object
     * @returns {Promise<void>}             - promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJob(session: Session, jobname: string, jobid: string, version?: string): Promise<void>;
    /**
     * Cancel and purge a job
     * Alternative version of the cancel API accepting an IJob object returned from other APIs such as GetJobs and SubmitJobs
     * @static
     * @param {Session}         session     - connection info
     * @param {IJob}            job         - the job that you want to cancel
     * @param {string}          version     - version of cancel request
     * @returns {Promise<void>}             - promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJobForJob(session: Session, job: zowe.IJob, version?: string): Promise<IRestApiResponse>;
    /**
     * Cancel and purge a job
     * Full version of the API with a parameter object
     * @static
     * @param {Session}             session     - connection info
     * @param {ICancelJobParms}     parms       - parm object (see ICancelJobParms interface for details)
     * @returns {Promise<void>}                 - promise that resolves when the API call is complete
     * @memberof CancelJobs
     */
    static cancelJobCommon(session: Session, parms: zowe.ICancelJobParms): Promise<void>;
    /**
     * Getter for brightside logger
     * @returns {Logger}
     */
    private static get log();
}
