/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
/**
 * Defaults to be used as options for the different types of data sets that can be created
 */
export declare const CreateDefaults: {
    /**
     * Specifies all the defaults to create non-vsam data sets
     */
    DATA_SET: {
        /**
         * Specifies the defaults used by the Zos Files API to create a partitioned data set
         * @type {ICreateDataSetOptions}
         */
        PARTITIONED: {
            allocationUnit: string;
            dataSetOrganization: string;
            primary: number;
            secondary: number;
            directoryBlocks: number;
            recordFormat: string;
            blockSize: number;
            recordLength: number;
        };
        /**
         * Specifies the defaults used by the Zos Files API to create a sequential data set
         * @type {ICreateDataSetOptions}
         */
        SEQUENTIAL: {
            allocationUnit: string;
            dataSetOrganization: string;
            primary: number;
            secondary: number;
            directoryBlocks: number;
            recordFormat: string;
            blockSize: number;
            recordLength: number;
        };
        /**
         * Specifies the defaults used by the Zos Files API to create a data set used for C code
         * @type {ICreateDataSetOptions}
         */
        C: {
            allocationUnit: string;
            dataSetOrganization: string;
            primary: number;
            secondary: number;
            directoryBlocks: number;
            recordFormat: string;
            blockSize: number;
            recordLength: number;
        };
        /**
         * Specifies the defaults used by the Zos Files API to create a classic data set
         * @type {ICreateDataSetOptions}
         */
        CLASSIC: {
            allocationUnit: string;
            dataSetOrganization: string;
            primary: number;
            secondary: number;
            directoryBlocks: number;
            recordFormat: string;
            blockSize: number;
            recordLength: number;
        };
    };
    USS: {
        CREATE: {
            permissions: string;
            file: string;
            folder: string;
        };
    };
};
