/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
/**
 * This class holds helper functions that are used to delete files through the
 * RSE APIs.
 */
export declare class Delete {
    /**
     * Deletes a non-VSAM data set
     *
     * @param {Session}               session      RSE connection info
     * @param {string}                dataSetName  The name of the data set to delete
     * @param {IDeleteDatasetOptions} [options={}] Additional options for deletion of the data set
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the status of the deletion
     *
     * @throws {ImperativeError} Data set name must be specified as a non-empty string
     * @throws {Error} When the rest api throws an error
     */
    static dataSet(session: Session, dataSetName: string, options?: zowe.IDeleteDatasetOptions): Promise<IRestApiResponse>;
    /**
     * Deletes a USS file or directory
     *
     * @param {Session}                   session      RSE connection info
     * @param {string}                    fileName     The name of the file or directory to delete
     * @param {boolean}                   recursive    The indicator to delete directory recursively
     * @returns {Promise<IDeleteVsamResponse>} A response indicating the status of the deletion
     *
     * @throws {ImperativeError} Data set name must be specified as a non-empty string
     */
    static ussFile(session: Session, fileName: string, recursive?: boolean): Promise<IRestApiResponse>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
