/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
/**
 * Class to handle downloading of job information
 * @export
 * @class DownloadJobs
 */
export declare class DownloadJobs {
    /**
     * Default directory where output will be placed
     * @static
     * @type {string}
     * @memberof DownloadJobs
     */
    static readonly DEFAULT_JOBS_OUTPUT_DIR: string;
    /**
     * Default extension of downloaded folders
     * @static
     * @type {string}
     * @memberof DownloadJobs
     */
    static readonly DEFAULT_JOBS_OUTPUT_FILE_EXT: string;
    /**
     * Download all job output (spool content) for a job to a the local directory
     * @static
     * @param {Session} session - connection info
     * @param {IDownloadAllSpoolContentParms} parms - parameter object (see IDownloadAllSpoolContentParms for details)
     * @returns {Promise<any>} - a promise which will resolve when the download is complete
     * @memberof DownloadJobs
     */
    static downloadAllSpoolContentCommon(session: zowe.imperative.Session, parms: zowe.IDownloadAllSpoolContentParms): Promise<any>;
    /**
     * Download spool content to specified directory
     * @static
     * @param {Session} session - connection info
     * @param {IDownloadSpoolContentParms} parms - parm object (see IDownloadSpoolContentParms interface for details)
     * @returns {Promise<void>} - promise that resolves when the file is downloaded
     * @memberof DownloadJobs
     */
    static downloadSpoolContentCommon(session: zowe.imperative.Session, jobName: string, jobId: string, extension: string, jobFile: zowe.IJobFile, parms: zowe.IDownloadSpoolContentParms): Promise<IRestApiResponse>;
    /**
     * Get the file where a specified spool file (IJobFile) would be downloaded to
     * @static
     * @param {IJobFile} jobFile - the spool file that would be downloaded
     * @param {boolean} omitJobidDirectory - if true, the job ID of the jobFile will not be included in the file path
     * @param {string} outDir - parent output directory you would like to download to
     * @param {string} extension - the extension of the spool files being downloaded
     * @returns {string} the file path that the spool file would be downloaded to
     * @memberof DownloadJobs
     */
    static getSpoolDownloadFile(jobFile: zowe.IJobFile, outDir: string, omitJobidDirectory?: boolean, extension?: string): string;
}
