/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IDownloadRseOptions } from './doc/IDownloadRseOptions';
/**
 * This class holds helper functions that are used to download data sets, members and more through the RSE APIs
 */
export declare class GetContent {
    /**
     * Retrieve USS file content to save it in your local workspace.
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           ussFileName  - contains the USS file name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} USS file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static ussFile(session: zowe.imperative.Session, ussFileName: string, destination: string, options: Partial<IDownloadRseOptions>): Promise<IRestApiResponse>;
    /**
     * Retrieve Dataset Member content to save it in your local workspace.
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           ussFileName  - contains the USS file name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} Dataset Member file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static dataSet(session: zowe.imperative.Session, dataSetName: string, destination: string, options?: IDownloadRseOptions): Promise<IRestApiResponse>;
    /**
     * Retrieve Job Spool content to save it in your local workspace.
     *
     * @param {Session}                     session      - RSE connection info
     * @param {IDownloadSpoolContentParms}  [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} Dataset Member file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static jobOutput(session: zowe.imperative.Session, jobFile: zowe.IJobFile, destination: string, parms?: zowe.IDownloadSpoolContentParms): Promise<IRestApiResponse>;
    private static jobOutputOldApi;
}
