/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import { IRestApiResponse } from '../../../api/doc/IRestApiResponse';
import { IRecallOptions } from './doc/IRecallOptions';
/**
 * This class holds helper functions that are used to recall files through the
 * z/OSMF APIs.
 */
export declare class HRecall {
    /**
     *
     * @param {Session}               session      RSE connection info
     * @param {string}                dataSetName  The name of the data set to recall
     * @param {boolean}               wait If true then the function waits for completion of the request. If false (default) the request is queued.
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the status of the recalling
     *
     * @throws {ImperativeError} Data set name must be specified as a non-empty string
     * @throws {Error} When the {@link ZosmfRestClient} throws an error
     *
     * @see https://www.ibm.com/support/knowledgecenter/SSLTBW_2.1.0/com.ibm.zos.v2r1.izua700/IZUHPINFO_API_PutDataSetMemberUtilities.htm
     */
    static dataSet(session: Session, dataSetName: string, options?: Partial<IRecallOptions>): Promise<IRestApiResponse>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
