/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
export declare class List {
    /**
     * REST API to retrieve a list of file meta-data from USS
     * @param session
     * @param path the path of the files to retrieve
     */
    static fileList(session: zowe.imperative.Session, path: string, showAdditionalAttributes?: boolean): Promise<IRestApiResponse>;
    /**
     * REST API to retrieve a list of data sets for a filter.
     * @param session
     * @param filter filter for a dataset query.
     */
    static dataSet(session: zowe.imperative.Session, filter: string, options?: zowe.IListOptions): Promise<IRestApiResponse>;
    /**
     * List data sets that match a DSLEVEL pattern
     * @param {zowe.imperative.Session} session rse connection info
     * @param {string[]} patterns Data set patterns to include
     * @param {IDsmListOptions} options Contains options for the rse request
     * @returns {Promise<IZosFilesResponse>} List of rse list responses for each data set
     */
    static dataSetsMatchingPattern(session: zowe.imperative.Session, patterns: string[], options?: zowe.IDsmListOptions): Promise<zowe.IZosFilesResponse>;
    /**
     * REST API to retrieve a list of data sets members.
     * @param session
     * @param dataSetName
     */
    static allMembers(session: zowe.imperative.Session, dataSetName: string, options?: zowe.IListOptions): Promise<IRestApiResponse>;
}
