/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as imperative from '@zowe/imperative';
import { IJob, IJobFile } from '../doc';
import { IHeaderContent } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
/**
 * This is a simple sleep function to help when waiting for a certain period of
 * time before continuing.
 *
 * @param {number} [ms=1000] The number of milliseconds to sleep.
 *
 * @returns {Promise<void>} Resolves after the specified time is up.
 *
 * @example <caption>Sleeping within code</caption>
 *
 * async function doStuff() {
 *   await CoreUtils.sleep(10000);
 *   console.log("You will see this message 10 seconds after function was entered");
 * }
 */
export declare function sleep(ms?: number): Promise<void>;
/**
 * Execute multiple promises in a pool with a maximum number of promises
 * executing at once
 * @param poolLimit - limit of how many promises should execute at once
 * @param array - array of objects to convert to promises with iteratorFn
 * @param iteratorFn - the function that turns an entry in the array into a promise
 */
export declare function asyncPool(poolLimit: number, array: any[], iteratorFn: (item: any, array: any[]) => Promise<any>): Promise<any>;
export declare function checkForToken(session: imperative.Session): IHeaderContent;
export declare function checkForLiveToken(session: imperative.Session, expiration: number): IHeaderContent;
export declare function isTokenDead(expirationTime: number): boolean;
export declare function calculateRemainingTime(expirationTime: number): number;
export declare function checkForJclSymbols(parms: zowe.ISubmitJobParms | zowe.ISubmitJclParms): IHeaderContent;
export declare function getAdditionalAttributes(): IHeaderContent;
export declare function setRestCommandFullHeaders(session: imperative.Session): IHeaderContent;
export declare function setHeaders(session: imperative.Session, parms?: zowe.ISubmitJobParms | zowe.ISubmitJclParms): IHeaderContent[];
export declare function getUserHome(): string | undefined;
export declare function apiVersionCheck(session: imperative.Session, version: number[]): Promise<void>;
export declare function readLocalFile(filePath: string): Promise<string>;
/**
 *
 * Builds the endpoint for RSE API calls.  The if/else check is for auto-init config files
 * that add '/api/v1' to the basePath.
 * TO DO: adjust this method for v2 paths if changes are made
 *
 * @param {Session}  session      - RSE connection info
 * @param {string}   endpoint     - RSE API endpoint
 *
 * @returns {string} Returns the endpoint for the RSE API calls
 *
 */
export declare function endpointBuilder(session: imperative.Session, endpoint: string): string;
export declare function rsePathEncode(ussPath: string): string;
export declare function getHttpsErrorMessage(statusCode: number): string;
/**
 * Constants and utilities used in tracking status of a running task
 */
export declare class TaskProgress {
    static readonly ZERO_PERCENT = 0;
    static readonly TEN_PERCENT = 10;
    static readonly TWENTY_PERCENT = 20;
    static readonly THIRTY_PERCENT = 30;
    static readonly FOURTY_PERCENT = 40;
    static readonly FIFTY_PERCENT = 50;
    static readonly SIXTY_PERCENT = 60;
    static readonly SEVENTY_PERCENT = 70;
    static readonly EIGHTY_PERCENT = 80;
    static readonly NINETY_PERCENT = 90;
    static readonly ONE_HUNDRED_PERCENT = 100;
}
/**
 * translate attributes of a response object to its proper keys
 * @param attributes zowe.IZosFilesResponse
 * @returns zowe.IZosFilesResponse
 */
export declare function translateAttributes(attributes: zowe.IZosFilesResponse): zowe.IZosFilesResponse;
/**
 * translate attributes of a response object to its proper keys
 * @param attributes zowe.IZosFilesResponse
 * @returns zowe.IZosFilesResponse
 */
export declare function translateMemberAttributes(attributes: zowe.IZosFilesResponse): zowe.IZosFilesResponse;
/**
 * translate properties of IJobFile to proper interface keys of zowe.IJobFile
 * @param jobFile IJobFile
 * @returns zowe.IJobFile
 */
export declare function translateJobFile(jobFile: IJobFile): zowe.IJobFile;
/**
 * translate properties of IJob to proper interface keys of zowe.IJob
 * @param job IJob
 * @returns zowe.IJob
 */
export declare function translateJob(job: IJob): zowe.IJob;
