/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
declare const _default: {
    AUTH: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            LOGIN: {
                SUMMARY: string;
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            REFRESH_TOKEN: {
                SUMMARY: string;
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            LOGOUT: {
                SUMMARY: string;
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            QUERY: {
                SUMMARY: string;
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    COMMON: {
        ATTRIBUTE_TITLE: string;
        FOR: string;
        TO: string;
        WITH_VALUE: string;
    };
    CANCEL: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            JOB: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    CHANGE: {
        DESCRIPTION: string;
        ACTIONS: {
            PASSWORD: {
                DESCRIPTION: string;
                POSITIONALS: {
                    CURRENTPASSWORD: string;
                    NEWPASSWORD: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            PROPERTIES: {
                DESCRIPTION: string;
                POSITIONALS: {
                    FILE: string;
                };
                OPTIONS: {
                    OWNER: string;
                    GROUP: string;
                    PERMISSIONS: string;
                    TAG: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    CHECK: {
        DESCRIPTION: string;
        ACTIONS: {
            STATUS: {
                DESCRIPTION: string;
            };
            MAPPINGS: {
                DESCRIPTION: string;
                OPTIONS: {
                    FORCE: string;
                };
            };
            SYSTEM: {
                DESCRIPTION: string;
            };
            JOB: {
                DESCRIPTION: string;
                OPTIONS: {
                    ASID: string;
                    SWAPIN: string;
                    CPU: string;
                    ASIDX: string;
                    PAGE: string;
                    USERID: string;
                    IO: string;
                    TYPE: string;
                    DP: string;
                    CPU_PERCENT: string;
                    NAME: string;
                    BYTES: string;
                    ELAPSED: string;
                    HVCOMUSED: string;
                    TASK_PERCENT: string;
                    HVCOMHWM: string;
                    TASK: string;
                    FRAMES: string;
                    SUBTYPE: string;
                    SYSNAME: string;
                    POSITION: string;
                    STEPIO: string;
                    DESCRIPTION: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            EXPIRY: {
                DESCRIPTION: string;
            };
        };
    };
    COPY: {
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    FROMDATASETNAME: string;
                    TODATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            USS_FILE: {
                DESCRIPTION: string;
                POSITIONALS: {
                    PATH: string;
                    DESTINATION: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
        };
    };
    CREATE: {
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            DATA_SET_PARTITIONED: {
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            DATA_SET_SEQUENTIAL: {
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            MEMBER: {
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                };
            };
            USS_FILE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    USSPATH: string;
                };
                OPTIONS: {
                    MODE: string;
                };
                EXAMPLES: {
                    CREATE_FILE: string;
                    SPECIFY_MODE: string;
                };
            };
            USS_DIR: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    USSPATH: string;
                };
                OPTIONS: {
                    MODE: string;
                };
                EXAMPLES: {
                    CREATE_DIRECTORY: string;
                    SPECIFY_MODE: string;
                };
            };
        };
        POSITIONALS: {
            DATASETNAME: string;
            MEMBER: string;
        };
        OPTIONS: {
            VOLSER: string;
            UNIT: string;
            DSORG: string;
            ALCUNIT: string;
            PRIMARY: string;
            SECONDARY: string;
            DIRBLK: string;
            AVGBLK: string;
            RECFM: string;
            BLKSIZE: string;
            LRECL: string;
            STORECLASS: string;
            MGNTCLASS: string;
            DATACLASS: string;
            DSNTYPE: string;
            FLATFILE: string;
            SHOWATTRIBUTES: string;
            SIZE: string;
        };
    };
    DELETE: {
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    DSNAME: string;
                };
                OPTIONS: {
                    VOLUME: string;
                    FOR_SURE: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            USS: {
                DESCRIPTION: string;
                POSITIONALS: {
                    FILENAME: string;
                };
                OPTIONS: {
                    FOR_SURE: string;
                    RECURSIVE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            JOBS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    DOWNLOAD: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            ALL_MEMBERS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            DATA_SET: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            USS_FILE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    USSFILENAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            JOB_OUTPUT: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                };
                OPTIONS: {
                    DIRECTORY: string;
                    EXTENSION: string;
                    OMIT_JOB_DIRECTORY: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            DATA_SETS_MATCHING: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    PATTERN: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
        };
        OPTIONS: {
            VOLUME: string;
            BINARY: string;
            FILE: string;
            EXTENSION: string;
            DIRECTORY: string;
            EXTENSION_MAP: string;
            EXCLUDE_PATTERN: string;
            MAX_CONCURRENT_REQUESTS: string;
            ENCODING: string;
            MAPPINGSFILE: string;
        };
    };
    EXPORT: {
        DESCRIPTION: string;
        ACTIONS: {
            JOBSPOOL_TO_DATASET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBNAME: string;
                    JOBID: string;
                    SPOOLID: string;
                    TODATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
        };
    };
    HMIGRATE: {
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
        OPTIONS: {
            WAIT: string;
        };
    };
    HRECALL: {
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
        OPTIONS: {
            WAIT: string;
        };
    };
    ISSUE: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            COMMAND: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    COMMANDTEXT: string;
                };
                OPTIONS: {
                    SHELLID: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            SSH: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    COMMANDTEXT: string;
                };
                OPTIONS: {
                    CWD: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            UNIXSHELL: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    COMMANDTEXT: string;
                };
                OPTIONS: {
                    CWD: string;
                    ENV: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    LIST: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            ALL_MEMBERS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            DATA_SET: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                OPTIONS: {
                    ATTRIBUTES: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                    EX4: string;
                    EX5: string;
                };
            };
            JOBS: {
                SUMMARY: string;
                DESCRIPTION: string;
                OPTIONS: {
                    OWNER: string;
                    PREFIX: string;
                    STATUS: string;
                    ATTRIBUTES: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            SPOOL_FILE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            USS_FILE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    PATH: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
        };
        OPTIONS: {
            VOLUME: string;
            ATTRIBUTES: string;
            MAXLENGTH: string;
            PATH: string;
        };
    };
    RENAME: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            USS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    PATH: string;
                    NAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            DATA_SET: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATA_SET: string;
                    NAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            MEMBER: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATA_SET: string;
                    NAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    SEARCH: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            USS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    PATH: string;
                    FILENAME: string;
                };
                OPTIONS: {
                    TEXT: string;
                    REGEX_FILENAME: string;
                    REGEX_CONTENT: string;
                    CASE_SENSITIVE_FILENAME: string;
                    CASE_SENSITIVE_CONTENT: string;
                    PATH_RESULTS_ONLY: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    SUBMIT: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            DATA_SET: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            LOCAL_FILE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    LOCALFILE: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            STDIN: {
                SUMMARY: string;
                DESCRIPTION: string;
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
        };
        OPTIONS: {
            WAIT_FOR_OUTPUT: string;
            WAIT_FOR_ACTIVE: string;
            VIEW_ALL_SPOOL_CONTENT: string;
            DIRECTORY: string;
            EXTENSION: string;
            JCL_SYMBOLS: string;
        };
    };
    UPLOAD: {
        DESCRIPTION: string;
        ACTIONS: {
            DIR_TO_PDS: {
                DESCRIPTION: string;
                POSITIONALS: {
                    INPUTDIR: string;
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            FILE_TO_DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    INPUTFILE: string;
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            STDIN_TO_DATA_SET: {
                DESCRIPTION: string;
                POSITIONALS: {
                    DATASETNAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            FILE_TO_USS: {
                DESCRIPTION: string;
                POSITIONALS: {
                    INPUTFILE: string;
                    USSFILENAME: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
            DIR_TO_USS: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    INPUTDIR: string;
                    USSDIR: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                    EX4: string;
                    EX5: string;
                };
            };
        };
        OPTIONS: {
            VOLUME: string;
            BINARY: string;
            RECALL: string;
            RECURSIVE: string;
            BINARY_FILES: string;
            ASCII_FILES: string;
            ATTRIBUTES: string;
            MAX_CONCURRENT_REQUESTS: string;
            ENCODING: string;
            MAPPINGSFILE: string;
        };
    };
    VIEW: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            JOB_STATUS_BY_JOBID: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                };
                OPTIONS: {
                    ATTRIBUTES: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            SPOOL_FILE_BY_ID: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    JOBID: string;
                    SPOOL_FILE_ID: string;
                };
                EXAMPLES: {
                    EX1: string;
                };
            };
        };
    };
    COMMONPROPS: {
        SUMMARY: string;
        DESCRIPTION: string;
        ACTIONS: {
            COPY: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    FROM_NAMESPACENAME: string;
                    TO_NAMESPACENAME: string;
                };
                OPTIONS: {
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            CREATE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    NAMESPACENAME: string;
                };
                OPTIONS: {
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            DELETE: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    NAMESPACENAME: string;
                };
                OPTIONS: {
                    PATH: string;
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            LIST: {
                SUMMARY: string;
                DESCRIPTION: string;
                OPTIONS: {
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            RENAME: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    BEFORE_NAMESPACENAME: string;
                    AFTER_NAMESPACENAME: string;
                };
                OPTIONS: {
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
            SET: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    NAMESPACENAME: string;
                    PROPERTY_PATH: string;
                    PROPERTY_VALUE: string;
                };
                OPTIONS: {
                    PRIVATE: string;
                    TYPE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                    EX3: string;
                };
            };
            VIEW: {
                SUMMARY: string;
                DESCRIPTION: string;
                POSITIONALS: {
                    NAMESPACENAME: string;
                };
                OPTIONS: {
                    PATH: string;
                    PRIVATE: string;
                };
                EXAMPLES: {
                    EX1: string;
                    EX2: string;
                };
            };
        };
    };
};
export default _default;
