/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});const imperative_1=require("@zowe/imperative");exports.default={AUTH:{SUMMARY:"Connect to RSE API Server Authentication Service",DESCRIPTION:"Connect to the RSE API Server authentication service and obtain a token. The token provides authentication to services that are supported by the RSE API. When you log in, the token is stored in your profile until it expires. Profiles store connection information, and are used if you do not supply connection information in a command. To take advantage of the token authentication service, you should omit username and password in profiles so that the token in the profile is used.",ACTIONS:{LOGIN:{SUMMARY:"Log in to an authentication service to obtain a JWT Token.",DESCRIPTION:"Log in to an authentication service to obtain a JWT Token.",EXAMPLES:{EX1:"Obtain token by logging into an authentication service if username and password are not saved locally."}},REFRESH_TOKEN:{SUMMARY:"Refresh the current session and obtain a newer JWT Token.",DESCRIPTION:"Refresh the current session and obtain a newer JWT Token.",EXAMPLES:{EX1:"Extend a remote session beyond the timeout period of a JWT token."}},LOGOUT:{SUMMARY:"Log out of the authentication service and retire the JWT Token",DESCRIPTION:"Log out of the authentication service and retire the JWT Token",EXAMPLES:{EX1:"Retire JWT token from the authentication service."}},QUERY:{SUMMARY:"Get back JWT Token information if it is not yet expired.",DESCRIPTION:"Get back JWT Token information if it is not yet expired.",EXAMPLES:{EX1:"Obtain token information from the authentication service."}}}},COMMON:{ATTRIBUTE_TITLE:"The following attributes are used during creation:\n",FOR:"for",TO:"to",WITH_VALUE:"with value"},CANCEL:{SUMMARY:"Cancel a job",DESCRIPTION:"Cancel a single job by job ID. This cancels the job if it is running or on input.",ACTIONS:{JOB:{SUMMARY:"Cancel a single job by job ID",DESCRIPTION:"Cancel a single job by job ID",POSITIONALS:{JOBID:'The job ID (e.g. JOB00123) of the job. Job ID is a unique identifier for z/OS batch jobs -- no two jobs on one system can have the same ID. Note: z/OS allows you to abbreviate the job ID if desired. You can use, for example "J123".'},EXAMPLES:{EX1:"Cancel job with job ID JOB03456"}}}},CHANGE:{DESCRIPTION:"Change User Data on the Host",ACTIONS:{PASSWORD:{DESCRIPTION:"Change z/OS User Password on the Host. User will be prompted for user name, password, and new password.",POSITIONALS:{CURRENTPASSWORD:"Current password for z/OS User ID.",NEWPASSWORD:"New password for z/OS User ID. Must be 8 characters or less."},EXAMPLES:{EX1:"Change Password"}},PROPERTIES:{DESCRIPTION:"Change owner and permissions for a unix file",POSITIONALS:{FILE:"the file that will have its properties changed."},OPTIONS:{OWNER:"the new owner for the file.",GROUP:"the new group for the file.",PERMISSIONS:"the new permissions for the file.",TAG:"the new tag for the file"},EXAMPLES:{EX1:"Change Properties"}}}},CHECK:{DESCRIPTION:"Confirm that RSE API is running on a specified system and gather information about the RSE API server and Address Space for diagnostic purposes, and information about user password expiry. Obtain and update MVS mappings file",ACTIONS:{STATUS:{DESCRIPTION:"Confirm that RSE API is running on a system specified in your profile and gather information about the RSE API server for diagnostic purposes. The command outputs properties of the RSE API server such as version, hostname, and the port the server is running."},MAPPINGS:{DESCRIPTION:"Download MVS mapping file.",OPTIONS:{FORCE:"This will overwrite an existing rse-mappings.json file."}},SYSTEM:{DESCRIPTION:"Display active system address space information."},JOB:{DESCRIPTION:"Display all active job address space information.",OPTIONS:{ASID:"Address space identifier.",SWAPIN:"Swapped-in state.",CPU:"Accumulated CPU time consumed by and on behalf of and within the A/S, for the current job step, in microseconds (local + remote + external).",ASIDX:"Address space identifier in hexadecimal.",PAGE:"Demand paging rate for address space.",USERID:"User id of owner.",IO:"EXCP rate in EXCPs per second for address space.",TYPE:"Type of address space.",DP:"Address space dispatching priority in hexadecimal.",CPU_PERCENT:"Percent of all CPU time consumed by and on behalf of the address space during the most recent interval measured.",NAME:"Job name.",BYTES:"Current real storage usage in bytes.",ELAPSED:"Elapsed time the transaction has been active.",HVCOMUSED:"High virtual common memory size in MB.",TASK_PERCENT:"Accumulated CPU time consumed by and on behalf of the A/S, for the current job step, in microseconds (local + remote).",HVCOMHWM:"High virtual common memory high-water mark in MB.",TASK:"A/S CPU usage % of system total in interval - task (local + remote).",FRAMES:"Current utilization of real storage in frames.",SUBTYPE:"Sub-type of 1.job/initiator: JES, z/OS UNIX, or APPC, 2.started task: JES, MSTR, SYS.",SYSNAME:"System name where job is executing.",POSITION:"Address space position.",STEPIO:"A/S EXCP (I/O) count for the current job step.",DESCRIPTION:"Address space position description."},EXAMPLES:{EX1:"Display all active job address space information using filters for information to be shown"}},EXPIRY:{DESCRIPTION:"Displays expiration date of user id's password."}}},COPY:{DESCRIPTION:"Copy a z/OS UNIX System Services file/directory or data set",ACTIONS:{DATA_SET:{DESCRIPTION:"Copy a data set to another data set",POSITIONALS:{FROMDATASETNAME:"The name of the data set that you want to copy from",TODATASETNAME:"The name of the data set that you want to copy to (partitioned data set must be preallocated to copy a member to)"},EXAMPLES:{EX1:"Copy the data set member named 'USER.FROM.SET(MEM1)' to the data set member named 'USER.TO.SET(MEM2)'",EX2:"Copy the sequential data set named 'USER.FROM.PDSE' to the data set member named 'USER.TO.SETPDSE'"}},USS_FILE:{DESCRIPTION:"Copy a z/OS UNIX System Services file/directory to another directory",POSITIONALS:{PATH:"The working directory",DESTINATION:"The destination path of the new file to be appended to the parent path"},EXAMPLES:{EX1:"Copy the file named '/u/example1/test.txt' to the destination '/u/example2/test.txt'",EX2:"Copy the directory named '/u/example1' to the destination '/u/example2'"}}}},CREATE:{DESCRIPTION:"Create data sets, data set members or z/OS UNIX System Services files and directories",ACTIONS:{DATA_SET:{DESCRIPTION:"Create a data set based on the properties of an existing data set",EXAMPLES:{EX1:"Create a data set with default parameters and like flag",EX2:"Create a data set with default parameters, like flag, and lrecl flag"}},DATA_SET_PARTITIONED:{DESCRIPTION:"Create partitioned data sets (PDS)",EXAMPLES:{EX1:"Create an empty PDS with default parameters"}},DATA_SET_SEQUENTIAL:{DESCRIPTION:"Create physical sequential data sets (PS)",EXAMPLES:{EX1:"Create an empty physical sequential data set with default parameters"}},MEMBER:{DESCRIPTION:"Create a member for a Partitioned data set.",EXAMPLES:{EX1:"Create a new, empty member for a PDS."}},USS_FILE:{SUMMARY:"Create a z/OS UNIX System Services file",DESCRIPTION:"Create a z/OS UNIX System Services file.",POSITIONALS:{USSPATH:"The name of the file."},OPTIONS:{MODE:"File permissions, ex. `rwxrw-r--`"},EXAMPLES:{CREATE_FILE:'Create a z/OS UNIX System Services file named "test.ext" ',SPECIFY_MODE:'Create a z/OS UNIX System Services file named "text.txt" with mode "rwxrwxrwx" '}},USS_DIR:{SUMMARY:"Create a z/OS UNIX System Services directory",DESCRIPTION:"Create a z/OS UNIX System Services directory.",POSITIONALS:{USSPATH:"The name of the directory."},OPTIONS:{MODE:"Directory permissions, ex. `rwxrw-r--`"},EXAMPLES:{CREATE_DIRECTORY:'Create a z/OS UNIX System Services directory named "testDir" ',SPECIFY_MODE:'Create a z/OS UNIX System Services directory named "testDir" with mode "rwxrwxrwx" '}}},POSITIONALS:{DATASETNAME:"The name of the data set that you want to create",MEMBER:'The name of the data set member that you want to create like so "HLQ.DATASETNAME(NEWMEMBER)".'},OPTIONS:{VOLSER:"The volume serial (VOLSER) on which you want the data set to be placed. A VOLSER is analogous to a drive name on a PC.",UNIT:"The device type, also known as 'unit'",DSORG:"The data set organization",ALCUNIT:"The allocation unit (for example, CYL for Cylinders)",PRIMARY:"The primary space allocation (for example, 5)",SECONDARY:"The secondary space allocation (for example, 1)",DIRBLK:"The number of directory blocks (for example, 25)",AVGBLK:"The number of average blocks (for example, 25)",RECFM:'The record format for the data set (for example, FB for "Fixed Block")',BLKSIZE:"The block size for the data set (for example, 6160)",LRECL:"The logical record length. Analogous to the length of a line (for example, 80)",STORECLASS:"The SMS storage class to use for the allocation",MGNTCLASS:"The SMS management class to use for the allocation",DATACLASS:"The SMS data class to use for the allocation",DSNTYPE:"The data set type",FLATFILE:"Indicates that you want to create the data set as a physical sequential file (flat file). A physical sequential file differs from a partitioned data set (PDS) because it cannot contain members, only file contents.",SHOWATTRIBUTES:"Show the full allocation attributes",SIZE:"The size of the data set (specified as nCYL or nTRK - where n is the number of cylinders or tracks). Sets the primary allocation (the secondary allocation becomes ~10% of the primary)."}},DELETE:{DESCRIPTION:"Delete a data set or Unix System Services file",ACTIONS:{DATA_SET:{DESCRIPTION:"Delete a data set permanently",POSITIONALS:{DSNAME:"The name of the data set that you want to delete"},OPTIONS:{VOLUME:"The volume serial (VOLSER) where the data set resides. The option is required only when the data set is not catalogued on the system.",FOR_SURE:"Specify this option to confirm that you want to delete the data set permanently."},EXAMPLES:{EX1:"Delete the data set named 'ibmuser.cntl'"}},USS:{DESCRIPTION:"Delete a z/OS UNIX System Services file or directory permanently",POSITIONALS:{FILENAME:"The name of the file or directory that you want to delete"},OPTIONS:{FOR_SURE:"Specify this option to confirm that you want to delete the file or directory permanently.",RECURSIVE:"Delete directories recursively."},EXAMPLES:{EX1:"Delete the directory '/u/ibmuser/testcases'",EX2:"Delete the file named '/a/ibmuser/my_text.txt'",EX3:"Recursively delete the directory named '/u/ibmuser/testcases'"}},JOBS:{SUMMARY:"Delete a single job by job ID",DESCRIPTION:"Delete a single job by job ID",POSITIONALS:{JOBID:'The job ID (e.g. JOB00123) of the job. Job ID is a unique identifier for z/OS batch jobs -- no two jobs on one system can have the same ID. Note: z/OS allows you to abbreviate the job ID if desired. You can use, for example "J123".'},EXAMPLES:{EX1:"Delete job with job ID JOB03456."}}}},DOWNLOAD:{SUMMARY:"Download content from z/OS data sets, UNIX System Services files, and JOB Output to your PC.",DESCRIPTION:"Download content from z/OS data sets, UNIX System Services files, and JOB Output to your PC.",ACTIONS:{ALL_MEMBERS:{SUMMARY:"Download all members from a pds",DESCRIPTION:"Download all members from a partitioned data set to a local folder",POSITIONALS:{DATASETNAME:"The name of the data set from which you want to download members"},EXAMPLES:{EX1:'Download the members of the data set "ibmuser.loadlib" to the directory "loadlib/"',EX2:'Download the members of the data set "ibmuser.cntl" as a .jcl to the directory "jcl/"',EX3:'Download the members of the data set "ibmuser.cntl" as binary.'}},DATA_SET:{SUMMARY:"Download content from a z/OS data set",DESCRIPTION:"Download content from a z/OS data set to a local file",POSITIONALS:{DATASETNAME:"The name of the data set that you want to download"},EXAMPLES:{EX1:'Download the data set "ibmuser.loadlib(main)" to the local file "main.obj".',EX2:'Download the data set "ibmuser.loadlib(main)" to the local file "main.obj" in binary mode.'}},USS_FILE:{SUMMARY:"Download content from a z/OS UNIX System Services file",DESCRIPTION:"Download content from a z/OS UNIX System Services file to a local file on your PC",POSITIONALS:{USSFILENAME:"The name of the z/OS UNIX System Services file you want to download"},EXAMPLES:{EX1:'Download the file "/a/ibmuser/my_text.txt" to "./my_text.txt"',EX2:'Download the file "/a/ibmuser/my_text.txt" to "./my_text.txt" in binary mode'}},JOB_OUTPUT:{SUMMARY:"Download all job output to a directory",DESCRIPTION:"Download all job output to a local directory. Each spool DD will be downloaded to its own file in the directory.",POSITIONALS:{JOBID:"The z/OS JOBID of the job containing the spool files you want to view. No pre-validation of the JOBID is performed."},OPTIONS:{DIRECTORY:"The local directory you would like to download the output for the job to.",EXTENSION:"A file extension to save the job output with. Defaults to '.txt'.",OMIT_JOB_DIRECTORY:"If specified, job output will be saved directly to the specified directory rather than creating a subdirectory named after the ID of the job."},EXAMPLES:{EX1:"Download all the output of the job with job ID JOB00234 to an automatically generated directory."}},DATA_SETS_MATCHING:{SUMMARY:"Download multiple data sets at once",DESCRIPTION:"Download all data sets that match a DSLEVEL pattern (see help below). You can use several options to qualify which data sets will be skipped and how the downloaded files will be structured. Data sets that are neither physical sequential nor partitioned data sets (with members) will be excluded. ",POSITIONALS:{PATTERN:`The pattern or patterns to match data sets against. Also known as 'DSLEVEL'. The\n                    following special sequences can be used in the pattern:\n                    ${imperative_1.TextUtils.chalk.yellow("%")}: matches any single character\n                    ${imperative_1.TextUtils.chalk.yellow("*")}: matches any number of characters within a data set name qualifier (e.g.\n                    "ibmuser.j*.old" matches "ibmuser.jcl.old" but not "ibmuser.jcl.very.old")\n                    ${imperative_1.TextUtils.chalk.yellow("**")}: matches any number of characters within any number of data set name\n                    qualifiers (e.g. "ibmuser.**.old" matches both "ibmuser.jcl.old" and\n                    "ibmuser.jcl.very.old")\n                    However, the pattern cannot begin with any of these sequences.You can specify\n                    multiple patterns separated by commas, for example\n                    "ibmuser.**.cntl,ibmuser.**.jcl"`},EXAMPLES:{EX1:'Download all data sets beginning with "ibmuser" and ending with\n                    ".cntl" or ".jcl" to the local directory "jcl" to files with the extension ".jcl"',EX2:'Download all data sets that begin with "ibmuser.public.project" or\n                    "ibmuser.project.private", excluding those that end in "lib" to the local\n                    directory "project", providing a custom mapping of data set low level qualifier\n                    to local file extension'}}},OPTIONS:{VOLUME:"The volume serial (VOLSER) where the data set resides. You can use this option at any time. However, the VOLSER is required only when the data set is not cataloged on the system. A VOLSER is analogous to a drive name on a PC.",BINARY:"Download the file content in binary mode, which means that no data conversion is performed. The data transfer process returns each line as-is, without translation. No delimiters are added between records.",FILE:"The path to the local file where you want to download the content. When you omit the option, the command generates a file name automatically for you.",EXTENSION:'Save the local files with a specified file extension. For example, .txt. Or "" for no extension.  When no extension is specified, .txt is used as the default file extension.',DIRECTORY:"The directory to where you want to save the members. The command creates the directory for you when it does not already exist. By default, the command creates a folder structure based on the data set qualifiers. For example, the data set ibmuser.new.cntl's members are downloaded to ibmuser/new/cntl).",EXTENSION_MAP:'Use this option to map data set names that match your pattern to the desired\n            extension. A comma delimited key value pairing (e.g. "cntl=.jcl,cpgm=.c" to map\n            the last segment of each data set (also known as the "low level qualifier" to\n            the desired local file extension).',EXCLUDE_PATTERN:"Exclude data sets that match these DSLEVEL patterns. Any data sets that match this pattern will not be downloaded.",MAX_CONCURRENT_REQUESTS:"Specifies the maximum number of concurrent RSE API REST requests to download members. Increasing the value results in faster downloads. However, increasing the value increases resource consumption on z/OS and can be prone to errors caused by making too many concurrent requests. If the download process encounters an error, the following message displays:\nThe maximum number of TSO address spaces have been created. When you specify 0, Zowe CLI attempts to download all members at once without a maximum number of concurrent requests. ",ENCODING:"Upload the file content with encoding mode, which means that data conversion is performed using the file encoding specified.",MAPPINGSFILE:"Location of an alternate MVS Mappings file."}},EXPORT:{DESCRIPTION:"Export Z/OS files.",ACTIONS:{JOBSPOOL_TO_DATASET:{DESCRIPTION:"Export a JES job provided job name, ID, fileID, and MVS data set.",POSITIONALS:{JOBNAME:"Job Name",JOBID:"Job Id",SPOOLID:"Spool Id",TODATASETNAME:"MVS data set name to be exported to"},EXAMPLES:{EX1:"Export spool file to sequential data set, 'HLQ.SEQDS'",EX2:"Export spool file a data set member, 'HLQ.DSNAME(MEMBER)'"}}}},HMIGRATE:{DESCRIPTION:"Migrate data sets.",ACTIONS:{DATA_SET:{DESCRIPTION:"Migrate a data set.",POSITIONALS:{DATASETNAME:"The name of the data set you want to migrate."},EXAMPLES:{EX1:"Migrate a data set using default options"}}},OPTIONS:{WAIT:"If true then the function waits for completion of the request. If false the request is queued."}},HRECALL:{DESCRIPTION:"Recall migrated data sets.",ACTIONS:{DATA_SET:{DESCRIPTION:"Recall a migrated data set.",POSITIONALS:{DATASETNAME:"The name of the data set you want to recall."},EXAMPLES:{EX1:"Recall a data set using default options"}}},OPTIONS:{WAIT:"If true then the function waits for completion of the request. If false the request is queued."}},ISSUE:{SUMMARY:"Issue TSO and UNIX commands",DESCRIPTION:"Issue TSO and UNIX commands",ACTIONS:{COMMAND:{SUMMARY:"Issue a TSO command, only supported in RSE API v1.0.1 and higher",DESCRIPTION:"Creates a TSO address space, issues a TSO command through the newly createdaddress space, waits for the READY prompt to print the response, and terminatesthe TSO address space. All response data are returned to the user up to (but notincluding) the TSO 'READY' prompt.",POSITIONALS:{COMMANDTEXT:"The TSO command to issue."},OPTIONS:{SHELLID:"Specify this if you wish to reuse a shell.  Required for interactive TSO commands."},EXAMPLES:{EX1:'Issue the TSO command "status" to display information about jobs for your user ID',EX2:"Issue an interactive TSO command with shell-id."}},SSH:{SUMMARY:"Issue a UNIX command",DESCRIPTION:"issues a UNIX command",POSITIONALS:{COMMANDTEXT:"The UNIX command to issue."},OPTIONS:{CWD:"Working directory in which to execute the command."},EXAMPLES:{EX1:'Issue the UNIX command "ls" to display a list of items in the directory'}},UNIXSHELL:{SUMMARY:"Issue a UNIX shell command with streaming output",DESCRIPTION:"issue a UNIX shell command with streaming output",POSITIONALS:{COMMANDTEXT:"The UNIX command to issue."},OPTIONS:{CWD:"Working directory in which to execute the command.",ENV:"A comma-separated list of environment variables to be set in the executing shell."},EXAMPLES:{EX1:"Issue the UNIX command to display the content of a file."}}}},LIST:{SUMMARY:"List the details for data sets and the members in the data sets, z/OS UNIX System Services files and directories, and jobs and spool files.",DESCRIPTION:"List z/OS UNIX System Services file and folders, data sets and data set members, or jobs and spool files. Optionally, you can list their details and attributes.",ACTIONS:{ALL_MEMBERS:{SUMMARY:"List all members of a pds",DESCRIPTION:"List all members of a partitioned data set. To view additional information about each member, use the --attributes option under the Options section of this help text.",POSITIONALS:{DATASETNAME:"The name of the data set for which you want to list the members"},EXAMPLES:{EX1:'Show members of the data set "ibmuser.asm"',EX2:'Show attributes of members of the data set "ibmuser.cntl"',EX3:'Show the first 5 members of the data set "ibmuser.cntl"'}},DATA_SET:{SUMMARY:"List data sets",DESCRIPTION:"List data sets that match a pattern in the data set name",POSITIONALS:{DATASETNAME:"The name or pattern of the data set that you want to list"},OPTIONS:{ATTRIBUTES:"Display more information about each member. Data sets with an undefined record format display information related to executable modules. Variable and fixed block data sets display information about when the members were created and modified."},EXAMPLES:{EX1:'Show the data set "ibmuser.asm"',EX2:'Show attributes of the data set "ibmuser.cntl"',EX3:'Show all data sets of the user "ibmuser"',EX4:'Show attributes of all data sets of the user "ibmuser"',EX5:'Show the first 5 data sets of the user "ibmuser"'}},JOBS:{SUMMARY:"List z/OS jobs on JES spool/queues",DESCRIPTION:'List jobs on JES spool/queues. By default, the command lists jobs owned (owner) by the user specified in your profile. The default for prefix is "*". The default status is ALL. The command does not prevalidate your user ID. The command surfaces errors verbatim from the Jobs REST endpoints.',OPTIONS:{OWNER:'Specify the owner of the jobs you want to list. The owner is the individual/user who submitted the job OR the user ID assigned to the job. The command does not prevalidate the owner. You can specify a wildcard according to the Jobs REST endpoint documentation, which is usually in the form "USER*".',PREFIX:'Specify the job name prefix of the jobs you want to list. The command does not prevalidate the owner. You can specify a wildcard according to the Jobs REST endpoint documentation, which is usually in the form "JOB*".',STATUS:"Specify if you want to list ALL jobs or only ACTIVE, OUTPUT, or INPUT jobs.",ATTRIBUTES:"Display more information about each job."},EXAMPLES:{EX1:"List all jobs with default settings. The command returns jobs owned by your user ID with any job name",EX2:"List all ACTIVE jobs owned by user IDs starting with 'ibmu' and job names starting with 'myjo'",EX3:"List all jobs with default owner and prefix settings, displaying only the job ID of each job"}},SPOOL_FILE:{SUMMARY:"List spool files of a z/OS job",DESCRIPTION:"Given a z/OS job JOBID, list the spool files (DDs) for a z/OS job on the JES/spool queues. The command does not pre-validate the JOBID. The command presents errors verbatim from the RSE API Jobs REST endpoints.",POSITIONALS:{JOBID:"The z/OS JOBID of the job with the spool files you want to list. No pre-validation of the JOBID is performed."},EXAMPLES:{EX1:"List the spool files of the job with JOBID JOB00123"}},USS_FILE:{SUMMARY:"List z/OS UNIX System Services files",DESCRIPTION:"List z/OS UNIX System Services files and directories in a UNIX file path",POSITIONALS:{PATH:"The directory containing the files and directories to be listed"},EXAMPLES:{EX1:"Show the files and directories in path '/u/ibmuser'",EX2:"Show the files and directories in path '/u/ibmuser' displaying only the file or directory name",EX3:"Show the files and directories in path '/u/ibmuser' displaying the headers associated with the file detail"}}},OPTIONS:{VOLUME:"The volume serial (VOLSER) where the data set resides. You can use this option at any time. However, the VOLSER is required only when the data set is not cataloged on the system. A VOLSER is analogous to a drive name on a PC.",ATTRIBUTES:"Display more information about each member. Data sets with an undefined record format display information related to executable modules. Variable and fixed block data sets display information about when the members were created and modified.",MAXLENGTH:"The option --max-length specifies the maximum number of items to return. Skip this parameter to return all items. If you specify an incorrect value, the parameter returns up to 1000 items.",PATH:"Specifies the path where the file system is mounted. This option and --fsname are mutually exclusive."}},RENAME:{SUMMARY:"Rename a Data set, Data set member, File or Directory",DESCRIPTION:"Rename a Data set, Data set member,File or Directory",ACTIONS:{USS:{SUMMARY:"Rename a z/OS UNIX System Services file or directory.",DESCRIPTION:"Rename a z/OS UNIX System Services file or directory.",POSITIONALS:{PATH:"Existing z/OS UNIX System Services file or directory Path.",NAME:"New name of z/OS UNIX System Services file or directory."},EXAMPLES:{EX1:'Rename z/OS UNIX System Services file "fileName" to "newFileName".'}},DATA_SET:{SUMMARY:"Rename a Data Set.",DESCRIPTION:"Rename a Data Set.",POSITIONALS:{DATA_SET:"Existing data set name including HLQ.",NAME:"New name of data set"},EXAMPLES:{EX1:"Rename a Data Set name to a new name."}},MEMBER:{SUMMARY:"Rename a Data Set Member.",DESCRIPTION:"Rename a Data Set Member.",POSITIONALS:{DATA_SET:"Existing Data Set Member name including HLQ.",NAME:"New name of data set member"},EXAMPLES:{EX1:"Rename a Data Set Member name to a new name."}}}},SEARCH:{SUMMARY:"Search for Unix System Services Files or Data Sets",DESCRIPTION:"Search by filename, member name, and contents",ACTIONS:{USS:{SUMMARY:"If Regex pattern is not used, wildcard patterns are used.",DESCRIPTION:"Search for UNIX Files by specifying the path, file name, and text pattern.",POSITIONALS:{PATH:"The working directory. Example: /u/IBM/test.",FILENAME:"The name of the file to perform the action on. Example: test.txt or ***.txt"},OPTIONS:{TEXT:"The text pattern to be searched for in the provided file. Example: hello",REGEX_FILENAME:"Regex for filename. If Regex pattern is not used, wildcard patterns are used.",REGEX_CONTENT:"Regex for text pattern. If Regex pattern is not used, wildcard patterns are used.",CASE_SENSITIVE_FILENAME:"Case-sensitive search for filename",CASE_SENSITIVE_CONTENT:"Case-sensitive search for content",PATH_RESULTS_ONLY:"Reduce the response to only the path results"},EXAMPLES:{EX1:"Search for a Unix System Services file with a file format of *.txt in /u/myuser/myfiles"}}}},SUBMIT:{SUMMARY:"Submit z/OS jobs",DESCRIPTION:"Submit jobs (JCL) contained in data sets.",ACTIONS:{DATA_SET:{SUMMARY:"Submit a job contained in a data set",DESCRIPTION:"Submit a job (JCL) contained in a data set. The data set may be of type physical sequential or a PDS member. The command does not pre-validate the data set name. The command presents errors verbatim from the Jobs REST endpoints. For more information about Jobs API errors, see the Jobs API REST documentation.",POSITIONALS:{DATASETNAME:'The z/OS data set containing the JCL to submit. You can specify a physical sequential data set (for example, "DATA.SET") or a partitioned data set qualified by a member (for example, "DATA.SET(MEMBER)"). '},EXAMPLES:{EX1:'Submit the JCL in the data set "ibmuser.cntl(deploy)"',EX2:'Submit the JCL in the data set "ibmuser.cntl(deploy)", wait for the job to complete and print all output from the job'}},LOCAL_FILE:{SUMMARY:"Submit a job contained in a local file",DESCRIPTION:"Submit a job (JCL) contained in a local file. The command presents errors verbatim from the Jobs REST endpoints. For more information about Jobs API errors, see the Jobs API REST documentation.",POSITIONALS:{LOCALFILE:"The local file containing the JCL to submit. "},EXAMPLES:{EX1:'Submit the JCL in the file "iefbr14.txt"'}},STDIN:{SUMMARY:"Submit a job read from standard in",DESCRIPTION:"Submit a job (JCL) passed to the command via the stdin stream. The command presents errors verbatim from the Jobs REST endpoints. For more information about Jobs API errors, see the Jobs API REST documentation.",EXAMPLES:{EX1:'Submit the JCL using stdin from the command: cat "iefbr14.txt", and then wait for the job to enter OUTPUT status before completing the command',EX2:'Submit the JCL using stdin from the command: cat "iefbr14.txt", and then printing all spool output'}}},OPTIONS:{WAIT_FOR_OUTPUT:"Wait for the job to enter OUTPUT status before completing the command.",WAIT_FOR_ACTIVE:"Wait for the job to enter ACTIVE status before completing the command.",VIEW_ALL_SPOOL_CONTENT:"Print all spool output. If you use this option you will wait the job to complete.",DIRECTORY:"The local directory you would like to download the output of the job. Creates a subdirectory using the jobID as the name and files are titled based on DD names. If you use this option you will wait the job to complete.",EXTENSION:"A file extension to save the job output with. Default is '.txt'.",JCL_SYMBOLS:"A string of JCL symbols to use for substitution. For symbol values with no spaces: \"symbol1=value1 symbol2=value2 ...\". When a value contains spaces, enclose the value in single quotes: \"symbol1='value 1 with spaces' symbol2='value 2 with spaces'...\". To embed a single quote in a value, use two single quotes: \"NAME=O''Brian\"."}},UPLOAD:{DESCRIPTION:"Upload the contents of a file to z/OS data sets or to z/OS UNIX System Services",ACTIONS:{DIR_TO_PDS:{DESCRIPTION:"Upload files from a local directory to a partitioned data set (PDS)",POSITIONALS:{INPUTDIR:"The path for a local directory that you want to upload to a PDS",DATASETNAME:"The name of the partitioned data set to which you want to upload the files"},EXAMPLES:{EX1:'Upload a directory named "src" to a PDS named "ibmuser.src"',EX2:'Upload a directory named "src" to a migrated PDS named "ibmuser.src" and wait for it to be recalled'}},FILE_TO_DATA_SET:{DESCRIPTION:"Upload the contents of a file to a z/OS data set",POSITIONALS:{INPUTFILE:"The local file that you want to upload to a data set",DATASETNAME:"The name of the data set to which you want to upload the file"},EXAMPLES:{EX1:'Upload file contents to a sequential data set named "ibmuser.ps"',EX2:'Upload file contents to a PDS member named "ibmuser.pds(mem)"',EX3:"Upload file contents to a migrated data set and wait for it to be recalled"}},STDIN_TO_DATA_SET:{DESCRIPTION:"Upload the content of a stdin to a z/OS data set",POSITIONALS:{DATASETNAME:"The name of the data set to which you want to upload data"},EXAMPLES:{EX1:'Stream content from stdin to a sequential data set named "ibmuser.ps" from a Windows console',EX2:'Stream content from stdin to a partition data set member named "ibmuser.pds(mem)" from a Windows console',EX3:"Stream content from stdin to a migrated data set and wait for it to be recalled from a Windows console"}},FILE_TO_USS:{DESCRIPTION:"Upload content to a z/OS UNIX System Services file from local file",POSITIONALS:{INPUTFILE:"The local file that you want to upload to a z/OS UNIX System Services file",USSFILENAME:"The name of the z/OS UNIX System Services file to which you want to upload the file"},EXAMPLES:{EX1:'Upload to the z/OS UNIX System Services file "/a/ibmuser/my_text.txt" from the file "file.txt"'}},DIR_TO_USS:{SUMMARY:"Upload a local directory to a z/OS UNIX System Services directory",DESCRIPTION:"Upload a local directory to a z/OS UNIX System Services directory.\n\nAn optional .zosattributes file in the source directory can be used to control file conversion and tagging.\n\nAn example .zosattributes file:{{space}}{{space}}\n# pattern        local-encoding        remote-encoding{{space}}{{space}}\n# Don't upload the node_modules directory{{space}}{{space}\nnode_modules     -{{space}}{{space}\n# Don't upload files that start with periods{{space}}{{space}}\n.*               - {{space}}{{space}\n# Upload jpg images in binary{{space}}{{space}}\n*.jpg            binary                binary{{space}}{{space}}\n# Convert CICS Node.js profiles to EBCDIC{{space}}{{space}}\n*.profile        ISO8859-1             EBCDIC{{space}}{{space}}\n\nLines starting with the ‘#’ character are comments. Each line can specify up to three positional attributes:\n{{bullet}} A pattern to match a set of files. Pattern-matching syntax follows the same rules as those that apply in .gitignore files (note that negated patterns that begin with ‘!’ are not supported). See https://git-scm.com/docs/gitignore#_pattern_format.\nlocal-encoding, {{bullet}} A local-encoding to identify a file’s encoding on the local workstation. If '-' is specified for files that match the pattern are not transferred.\n{{bullet}} A remote-encoding to specify the file’s desired character set on z/OS UNIX System Services. This attribute must either match the local encoding or be set to EBCDIC. If set to EBCDIC, files are transferred in text mode and converted, otherwise they are transferred  in binary mode. Remote files are tagged either with the remote encoding or as binary. \n \nDue to a limitation, files that are transferred in text mode are converted to the default EBCDIC code page on the z/OS system. Therefore the only EBCDIC code page to specify as the remote encoding is the default code page for your system.\n\n A .zosattributes file can either be placed in the top-level directory you want to upload, or its location can be specified by using the --attributes parameter. .zosattributes files that are placed in nested directories are ignored.\n",POSITIONALS:{INPUTDIR:"The local directory path that you want to upload to a z/OS UNIX System Services directory",USSDIR:"The name of the z/OS UNIX System Services directory to which you want to upload the local directory"},EXAMPLES:{EX1:'Upload all files from the "local_dir" directory to the "/a/ibmuser/my_dir" z/OS UNIX System Services directory:"',EX2:'Upload all files from the "local_dir" directory and all its sub-directories, to the "/a/ibmuser/my_dir" z/OS UNIX System Services directory:',EX3:'Upload all files from the "local_dir" directory to the "/a/ibmuser/my_dir" z/OS UNIX System Services directory in default ASCII mode, while specifying a list of file names (without path) to be uploaded in binary mode:',EX4:'Upload all files from the "local_dir" directory to the "/a/ibmuser/my_dir" z/OS UNIX System Services directory in binary mode, while specifying a list of file names (without path) to be uploaded in ASCII mode:',EX5:'Recursively upload all files from the "local_dir" directory to the "/a/ibmuser/my_dir" z/OS UNIX System Services directory, specifying files to ignore and file encodings in the local file my_global_attributes:'}}},OPTIONS:{VOLUME:"The volume serial (VOLSER) where the data set resides. You can use this option at any time. However, the VOLSER is required only when the data set is not cataloged on the system. A VOLSER is analogous to a drive name on a PC.",BINARY:"Data content in binary mode, which means that no data conversion is performed. The data transfer process returns each record as-is, without translation. No delimiters are added between records.",RECALL:"The method by which migrated data set is handled. By default, a migrated data set is recalled synchronously. You can specify the following values: wait, nowait, error",RECURSIVE:"Upload all directories recursively.",BINARY_FILES:"Comma separated list of file names to be uploaded in binary mode. Use this option when you upload a directory in default ASCII mode, but you want to specify certain files to be uploaded in binary mode. All files matching specified file names will be uploaded in binary mode. If a .zosattributes file (or equivalent file specified via --attributes) is present, --binary-files will be ignored.",ASCII_FILES:"Comma separated list of file names to be uploaded in ASCII mode. Use this option when you upload a directory with --binary/-b flag, but you want to specify certain files to be uploaded in ASCII mode. All files matching specified file names will be uploaded in ASCII mode. If a .zosattributes file (or equivalent file specified via --attributes) is present, --ascii-files will be ignored.",ATTRIBUTES:"Path of an attributes file to control how files are uploaded",MAX_CONCURRENT_REQUESTS:"Specifies the maximum number of concurrent REST API requests to upload files. Increasing the value results in faster uploads. However, increasing the value increases resource consumption on z/OS and can be prone to errors caused by making too many concurrent requests. If the upload process encounters an error, the following message displays:\nThe maximum number of TSO address spaces have been created. When you specify 0, Zowe CLI attempts to upload all members at once without a maximum number of concurrent requests. ",ENCODING:"Upload the file content with encoding mode, which means that data conversion is performed using the file encoding specified.",MAPPINGSFILE:"Location of an alternate MVS Mappings file."}},VIEW:{SUMMARY:"View details of a z/OS job",DESCRIPTION:"View details of z/OS jobs on spool/JES queues.",ACTIONS:{JOB_STATUS_BY_JOBID:{SUMMARY:"View status details of a z/OS job",DESCRIPTION:'View status details of a single z/OS job on spool/JES queues. The command does not prevalidate the JOBID. The command presents errors verbatim from the Jobs REST endpoints (expect for "no jobs found").',POSITIONALS:{JOBID:"The z/OS JOBID of the job you want to view. No prevalidation of the JOBID is performed."},OPTIONS:{ATTRIBUTES:"Display more information about the job."},EXAMPLES:{EX1:"View status and other details of the job with the job ID JOB00123",EX2:'Print only the status (for example, "OUTPUT" or "ACTIVE") of the job with the job ID JOB00123'}},SPOOL_FILE_BY_ID:{SUMMARY:"View a spool file from a z/OS job",DESCRIPTION:"View the contents of a spool file from a z/OS job on spool/JES queues. The command does not pre-validate the JOBID or spool ID. The command presents errors verbatim from the Jobs REST endpoints.",POSITIONALS:{JOBID:"The z/OS JOBID of the job containing the spool file you want to view. No pre-validation of the JOBID is performed.",SPOOL_FILE_ID:'The spool file ID number for the spool file to view. Use the "zowe rse list spool-files-by-jobid" command to obtain spool ID numbers.No pre-validation of the ID is performed.'},EXAMPLES:{EX1:"View the spool file with ID 4 for the job with job ID JOB00123"}}}},COMMONPROPS:{SUMMARY:"Manage Common Properites",DESCRIPTION:"Manage Common Properties on z/OS RSE API server.",ACTIONS:{COPY:{SUMMARY:"Copy a namespace",DESCRIPTION:"Copy a Common Properties namespace.",POSITIONALS:{FROM_NAMESPACENAME:"The name of the Common Properties namespace that you want to copy from.",TO_NAMESPACENAME:"The name of the Common Properties namespace that you want to copy to."},OPTIONS:{PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:"copy a public namespace",EX2:"copy a private namespace"}},CREATE:{SUMMARY:"Create a namespace",DESCRIPTION:"Create a Common Properties namespace.",POSITIONALS:{NAMESPACENAME:"The name of the Common Properties namespace."},OPTIONS:{PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:'Create a public namespace called "global-namespace"',EX2:'Create a user private namespace called "private-namespace"'}},DELETE:{SUMMARY:"Delete the namespace or a property in the namespace",DESCRIPTION:"Delete the namespace or a property in the namespace if --path option is specified.",POSITIONALS:{NAMESPACENAME:"The name of the Common Properties namespace."},OPTIONS:{PATH:"The path to the property in the Common Properties namespace.",PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:"Delete a private namespace",EX2:"Detete a property in a namespace"}},LIST:{SUMMARY:"List all namespaces",DESCRIPTION:"List all public or private Common Properties namespaces.",OPTIONS:{PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:"list all public Common Properties namespaces",EX2:"list all private Common Properties namespaces"}},RENAME:{SUMMARY:"Rename a namespace",DESCRIPTION:"Rename a Common Properties namespace.",POSITIONALS:{BEFORE_NAMESPACENAME:"The name of the Common Properties namespace that you want to rename.",AFTER_NAMESPACENAME:"The name you want to rename the Common Properties namespace to."},OPTIONS:{PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:"rename a public namespace",EX2:"rename a private namespace"}},SET:{SUMMARY:"Set a namespace property",DESCRIPTION:"Set a namespace property with a string, boolean, number or JSON string value.",POSITIONALS:{NAMESPACENAME:"The name of the Common Properties namespace.",PROPERTY_PATH:"The path to the property in the Common Properties namespace.",PROPERTY_VALUE:"The property value."},OPTIONS:{PRIVATE:"The namespace is a private Common Properties namespace if specified.",TYPE:"The property value type (string, number, boolean, json)"},EXAMPLES:{EX1:"set a string value to a property",EX2:"set a number value to a property",EX3:"set a JSON value to a property"}},VIEW:{SUMMARY:"View the namespace or a property in the namespace",DESCRIPTION:"View the namespace or a property in the namespace if --path option is specified.",POSITIONALS:{NAMESPACENAME:"The name of the Common Properties namespace."},OPTIONS:{PATH:"The path to the property in the Common Properties namespace.",PRIVATE:"The namespace is a private Common Properties namespace if specified."},EXAMPLES:{EX1:"View a property at the path in a private namespace",EX2:"View all properties in a public namespace"}}}}};